Mazepa: Lightweight Distributed Task Scheduling
===============================================

|CI Badge| |Codecov Badge| |Docs Badge| |Python Badge|

.. teaser-begin

``mazepa`` is TODO 

.. teaser-end


.. project-info-begin

Project Information
===================

- **License**: `MIT <https://choosealicense.com/licenses/mit/>`_
- **Source Code**: https://github.com/supersergiy/mazepa
- **Documentation**:  TODO 
- **Supported Python Versions**: 3.7 and later

.. project-info-end

..
  - **Changelog**:
  - **PyPI**: https://pypi.org/project/a


.. |CI Badge| image:: https://github.com/supersergiy/mazepa/actions/workflows/testing.yaml/badge.svg
  :target: https://github.com/supersergiy/mazepa/actions/workflows/testing.yaml
.. |Codecov Badge| image:: https://codecov.io/gh/supersergiy/mazepa/branch/main/graph/badge.svg?token=MGT3MDVTYZ
  :target: https://codecov.io/gh/supersergiy/mazepa

.. |Docs Badge| image:: https://github.com/supersergiy/mazepa/actions/workflows/docs_deployment.yaml/badge.svg?branch=main
  :target: https://github.com/supersergiy/mazepa/actions/workflows/docs_deployment.yaml
.. |Python Badge| image:: https://img.shields.io/badge/python-3.7+-blue.svg
